@@ -742,9 +742,9 @@ recode_polyploids <- function(poly, newploidy = FALSE, addzero = FALSE){
     warning("Input is not a polyploid data set, returning original.")
     return(poly)
   }
-  if (addzero && is.genind(poly)){
+  if (addzero && is.genind(poly)) {
     
-    if (test_zeroes(poly)){
+    if (test_zeroes(poly)) {
       warning("addzero = TRUE, but data already has zeroes. Returning original.")
       return(poly)
     }
@@ -755,7 +755,7 @@ recode_polyploids <- function(poly, newploidy = FALSE, addzero = FALSE){
                           pop = pop(poly), strata = strata(poly), 
                           hierarchy = poly@hierarchy)
     other(res) <- other(poly)
-    if (is.genclone(poly)){
+    if (is.genclone(poly)) {
       res <- as.genclone(res, mlg = poly@mlg)
     }
     return(res)
@@ -783,64 +783,10 @@ recode_polyploids <- function(poly, newploidy = FALSE, addzero = FALSE){
 }
 
 
-#' Split samples from a genind object into pseudo-haplotypes
-#'
-#'
-#' @param gid   a [genind][adegenet::genind] object.
-#'
-#' @return a haploid genind object with an extra [strata][adegenet::strata]
-#'   column called "Individual".
-#' @export
-#' @md
-#' 
-#' @note The [other slot][adegenet::other] will not be copied over to the new
-#'   genind object.
-#'
-#' @seealso [poppr.amova()] [pegas::amova()] [as.genambig()]
-#' 
-#' @details
-#' Certain analyses, such as [amova][poppr.amova] work best if within-sample
-#' variance (error) can be estimated. Practically, this is performed by
-#' splitting the genotypes across all loci to create multiple haplotypes. This
-#' way, the within-sample distance can be calculated and incorporated into the
-#' model. Please note that the haplotypes generated are based on the order of
-#' the unphased alleles in the genind object and do not represent true
-#' haplotypes. 
-#' 
-#' Haploid data will be returned un-touched.
-#'
-#' @examples
-#' # Diploid data is doubled -------------------------------------------------
-#' 
-#' data(nancycats)
-#' nan9 <- nancycats[pop = 9]
-#' nan9hap <- make_haplotypes(nan9) 
-#' nan9              # 9 individuals from population 9
-#' nan9hap           # 18 haplotypes
-#' strata(nan9hap)   # strata gains a new column: Individual
-#' indNames(nan9hap) # individuals are renamed sequentially
-#' 
-#' 
-#' # Mix ploidy data can be split, but should be treated with caution --------
-#' # 
-#' # For example, the Pinf data set contains 86 tetraploid individuals, 
-#' # but there appear to only be diploids and triploid genotypes. When 
-#' # we convert to haplotypes, those with all missing data are dropped.
-#' data(Pinf)
-#' Pinf
-#' pmiss <- info_table(Pinf, type = "ploidy", plot = TRUE)
-#' 
-#' # No samples appear to be triploid across all loci. This will cause
-#' # several haplotypes to have a lot of missing data.
-#' p_haps <- make_haplotypes(Pinf)
-#' p_haps
-#' head(genind2df(p_haps), n = 20)
-make_haplotypes <- function(gid) {
-  if (!is.genind(gid)) {
-    stop("make_haplotypes() can only take genind objects.")
-  }
+
+make_haplotypes_genind <- function(gid) {
   ploidy <- max(ploidy(gid))
-  if (ploidy == 1){
+  if (ploidy == 1) {
     warning("This procedure does not work on haploid data. Returning data.")
     return(gid)
   }
@@ -861,3 +807,35 @@ make_haplotypes <- function(gid) {
   setPop(newgid) <- ~Individual
   return(newgid)
 }
+
+make_haplotypes_genlight <- function(gid) {
+  ploidy <- max(ploidy(gid))
+  if (ploidy == 1) {
+    warning("This procedure does not work on haploid data. Returning data.")
+    return(gid)
+  }
+  if (is.null(strata(gid))) {
+    warning("No strata found... creating one from the population.")
+    strata(gid) <- data.frame(pop = pop(gid))
+  }
+  if (is.null(indNames(gid))) {
+    indNames(gid) <- .genlab("ind", nInd(gid))
+  }
+  addStrata(gid) <- data.frame(Individual = indNames(gid))
+  df             <- strata(gid)
+  df             <- df[rep(seq(nrow(df)), each = ploidy), , drop = FALSE]
+  newgid         <- lapply(gid@gen, function(x, p) lapply(seq(p), split_gen, x), ploidy)
+  newgid         <- new("genlight", unlist(newgid, recursive = FALSE, use.names = FALSE))
+  ploidy(newgid) <- 1L
+  alleles(newgid) <- alleles(gid)
+  strata(newgid)  <- df
+  setPop(newgid)  <- ~Individual
+  return(newgid)
+}
+
+split_gen <- function(i, gen) {
+  no_snps <- is.null(gen@snp[i][[1L]])
+  gen@snp <- if (no_snps) list(as.raw(rep(0L, length(gen@snp[[1L]])))) else gen@snp[i]
+  ploidy(gen) <- 1L
+  gen
+}
