@@ -89,9 +89,23 @@
 #'   
 #' @author Zhian N. Kamvar, Jonah C. Brooks
 #' @examples
+#' 
+#' # Basic usage example: Bruvo's Distance --------------------------------
 #' data(Pinf)
 #' pinfreps <- fix_replen(Pinf, c(2, 2, 6, 2, 2, 2, 2, 2, 3, 3, 2))
-#' filter_stats(Pinf, distance = bruvo.dist, replen = pinfreps, plot = TRUE, threads = 1L)
+#' bres <- filter_stats(Pinf, distance = bruvo.dist, replen = pinfreps, plot = TRUE, threads = 1L)
+#' print(bres) # shows all of the statistics
+#' 
+#' # Use these results with cutoff_filter()
+#' print(thresh <- cutoff_predictor(bres$farthest$THRESHOLDS))
+#' mlg.filter(Pinf, distance = bruvo.dist, replen = pinfreps) <- thresh
+#' Pinf 
+#' 
+#' # Different distances will give different results -----------------------
+#' nres <- filter_stats(Pinf, distance = nei.dist, plot = TRUE, threads = 1L, missing = "mean")
+#' print(thresh <- cutoff_predictor(nres$farthest$THRESHOLDS))
+#' mlg.filter(Pinf, distance = nei.dist, missing = "mean") <- thresh
+#' Pinf 
 #==============================================================================#
 filter_stats <- function(x, distance = bitwise.dist,
                          threshold = 1e6 + .Machine$double.eps^0.5, 
@@ -107,6 +121,7 @@ filter_stats <- function(x, distance = bitwise.dist,
   } else {
     distmat <- distance
   }
+  stats <- match.arg(toupper(stats), c("ALL", "MLG", "THRESHOLDS", "DISTANCES", "SIZES"))
   f <- mlg.filter(x, threshold, missing, algorithm = "f", distance = distmat, 
                   stats = stats, threads = threads, ...)
   a <- mlg.filter(x, threshold, missing, algorithm = "a", distance = distmat, 
@@ -114,8 +129,8 @@ filter_stats <- function(x, distance = bitwise.dist,
   n <- mlg.filter(x, threshold, missing, algorithm = "n", distance = distmat, 
                   stats = stats, threads = threads, ...)
   fanlist <- list(farthest = f, average = a, nearest = n)
-  if (stats == "All"){
-    if (plot){
+  if (stats %in% c("ALL", "THRESHOLDS")){
+    if (plot) {
       plot_filter_stats(x, fanlist, distmat, cols, nclone, hist)
       return(invisible(fanlist))
     }
@@ -213,9 +228,9 @@ plot_filter_stats <- function(x, fstats, distmat, cols = NULL, nclone = NULL, br
   plot(x = c(upper, 0), y = ylims, type = "n",
        ylab = "Number of Multilocus Lineages",
        xlab = "Genetic Distance Cutoff")
-  a <- fstats$average$THRESHOLDS
-  n <- fstats$nearest$THRESHOLDS
-  f <- fstats$farthest$THRESHOLDS
+  a <- if (inherits(fstats[[1]], "list")) fstats$average$THRESHOLDS else fstats$average
+  n <- if (inherits(fstats[[2]], "list")) fstats$nearest$THRESHOLDS else fstats$nearest
+  f <- if (inherits(fstats[[3]], "list")) fstats$farthest$THRESHOLDS else fstats$farthest
   plotcols <- c("#E41A1C", "#377EB8", "#4DAF4A") # RColorBrewer::brewer.pal(3, "Set1")
   names(plotcols) <- c("f", "a", "n")
   points(x = rev(a), y = 1:length(a), col = plotcols["a"])
