@@ -8,9 +8,10 @@
 */
 
 /* .Call calls */
+extern SEXP adjust_missing(SEXP, SEXP);
 extern SEXP association_index_diploid(SEXP, SEXP, SEXP, SEXP);
 extern SEXP association_index_haploid(SEXP, SEXP, SEXP);
-extern SEXP bitwise_distance_diploid(SEXP, SEXP, SEXP, SEXP);
+extern SEXP bitwise_distance_diploid(SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP bitwise_distance_haploid(SEXP, SEXP, SEXP);
 extern SEXP bruvo_distance(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP expand_indices(SEXP, SEXP);
@@ -26,9 +27,10 @@ extern SEXP permute_shuff(SEXP, SEXP, SEXP);
 extern SEXP permuto(SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
+    {"adjust_missing",            (DL_FUNC) &adjust_missing,            2},
     {"association_index_diploid", (DL_FUNC) &association_index_diploid, 4},
     {"association_index_haploid", (DL_FUNC) &association_index_haploid, 3},
-    {"bitwise_distance_diploid",  (DL_FUNC) &bitwise_distance_diploid,  4},
+    {"bitwise_distance_diploid",  (DL_FUNC) &bitwise_distance_diploid,  5},
     {"bitwise_distance_haploid",  (DL_FUNC) &bitwise_distance_haploid,  3},
     {"bruvo_distance",            (DL_FUNC) &bruvo_distance,            6},
     {"expand_indices",            (DL_FUNC) &expand_indices,            2},
