@@ -12,10 +12,19 @@ test_that("resample.ia works out of the box", {
   expect_equal(ncol(x), 2L)
 })
 
-test_that("resample.ia balks at incorrect values of n", {
+test_that("boot.ia works out of the box", {
   skip_on_cran()
-  expect_error(resample.ia(jhc, n = nInd(jhc)), "n must be less")
+  x <- boot.ia(jhc)
+  expect_is(x, "data.frame")
+  expect_equal(nrow(x), 999L)
+  expect_equal(ncol(x), 2L)
+})
+
+test_that("resample and boot balk at incorrect values of n", {
+  skip_on_cran()
+  expect_error(resample.ia(jhc, n = nInd(jhc)), "n must be fewer")
   expect_error(resample.ia(jhc, n = 2), "n must be greater")
+  expect_error(boot.ia(jhc[1:2], how = "full"), "n must be greater")
 })
 
 data("Pinf")
